"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateOfferQuotes = exports.matchingOffersV2 = exports.matchingOffers = exports.REQUIRE_BUMP_PER_TRADE = exports.REQUIRE_ACCOUNT_PER_TRADE = void 0;
exports.REQUIRE_ACCOUNT_PER_TRADE = 6;
exports.REQUIRE_BUMP_PER_TRADE = 3;
function matchingOffers(offersData, tradeAmount) {
    // in-place sort offerData by available amount
    offersData.sort((a, b) => Number(a.availableAmount) - Number(b.availableAmount));
    // return first offer if available amount at first offer accept
    if (offersData[0].availableAmount.gte(tradeAmount)) {
        return [offersData[0]];
    }
    let start = 0;
    let end = offersData.length - 1;
    while (start < end) {
        const availableAmounts = offersData[start].availableAmount.add(offersData[end].availableAmount);
        if (availableAmounts.gte(tradeAmount)) {
            return [offersData[start], offersData[end]];
        }
        start += 1;
    }
    return [];
}
exports.matchingOffers = matchingOffers;
function matchingOffersV2(offersData, tradeAmount) {
    // in-place sort offerData by available amount
    offersData.sort((a, b) => Number(a.availableAmount) - Number(b.availableAmount));
    // return first offer if available amount at first offer accept
    if (offersData[0].availableAmount.gte(tradeAmount)) {
        return [offersData[0]];
    }
    let start = 0;
    let end = offersData.length - 1;
    while (start < end) {
        const availableAmounts = offersData[start].availableAmount.add(offersData[start + 1].availableAmount);
        if (availableAmounts.gte(tradeAmount)) {
            return [offersData[start], offersData[start + 1]];
        }
        start += 1;
    }
    return [];
}
exports.matchingOffersV2 = matchingOffersV2;
function validateOfferQuotes(offerQuote) {
    if (offerQuote.tradeIds.length != offerQuote.numOffers) {
        throw new Error(`Not Enough trade id for ${offerQuote.numOffers} trades`);
    }
    if (offerQuote.tradeAmounts.length != offerQuote.numOffers) {
        throw new Error(`Not Enough trade amount for ${offerQuote.numOffers} trades`);
    }
    if (offerQuote.bumps.length != offerQuote.numOffers * exports.REQUIRE_BUMP_PER_TRADE) {
        throw new Error(`Not Enough bumps for ${offerQuote.numOffers} trades`);
    }
    if (offerQuote.remainingAccounts.length != offerQuote.numOffers * exports.REQUIRE_ACCOUNT_PER_TRADE) {
        throw new Error(`Not Enough vault account for ${offerQuote.numOffers} trades`);
    }
}
exports.validateOfferQuotes = validateOfferQuotes;
